"""


Motionpath Display Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:CURRENT_FRAME:   
  Around Frame.

  Display Paths of poses within a fixed number of frames around the current frame.

:RANGE:           
  In Range.

  Display Paths of poses within specified range.

.. _rna-enum-motionpath-display-type-items:

"""

import typing
