"""


Attribute Type Items
^^^^^^^^^^^^^^^^^^^^

:FLOAT:           
  Float.

  Floating-point value.

:INT:             
  Integer.

  32-bit integer.

:FLOAT_VECTOR:    
  Vector.

  3D vector with floating-point values.

:FLOAT_COLOR:     
  Color.

  RGBA color with 32-bit floating-point values.

:BYTE_COLOR:      
  Byte Color.

  RGBA color with 8-bit positive integer values.

:STRING:          
  String.

  Text string.

:BOOLEAN:         
  Boolean.

  True or false.

:FLOAT2:          
  2D Vector.

  2D vector with floating-point values.

:INT8:            
  8-Bit Integer.

  Smaller integer with a range from -128 to 127.

.. _rna-enum-attribute-type-items:

"""

import typing
