"""


Fileselect Params Sort Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILE_SORT_ALPHA: 
  Name.

  Sort the file list alphabetically.

:FILE_SORT_EXTENSION:
  Extension.

  Sort the file list by extension/type.

:FILE_SORT_TIME:  
  Modified Date.

  Sort files by modification time.

:FILE_SORT_SIZE:  
  Size.

  Sort files by size.

.. _rna-enum-fileselect-params-sort-items:

"""

import typing
