"""


bpy_extras submodule (bpy_extras.node_utils)
********************************************

:func:`find_node_input`

"""

import typing

def find_node_input(node: typing.Any, name: typing.Any) -> None:

  ...
