"""


Snap Element Items
^^^^^^^^^^^^^^^^^^

:INCREMENT:       
  Increment.

  Snap to increments of grid.

:VERTEX:          
  Vertex.

  Snap to vertices.

:EDGE:            
  Edge.

  Snap to edges.

:FACE:            
  Face Project.

  Snap by projecting onto faces.

:FACE_NEAREST:    
  Face Nearest.

  Snap to nearest point on faces.

:VOLUME:          
  Volume.

  Snap to volume.

:EDGE_MIDPOINT:   
  Edge Center.

  Snap to the middle of edges.

:EDGE_PERPENDICULAR:
  Edge Perpendicular.

  Snap to the nearest point on an edge.

.. _rna-enum-snap-element-items:

"""

import typing
