"""


Object Rotation Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:QUATERNION:      
  Quaternion (WXYZ).

  No Gimbal Lock.

:XYZ:             
  XYZ Euler.

  XYZ Rotation Order - prone to Gimbal Lock (default).

:XZY:             
  XZY Euler.

  XZY Rotation Order - prone to Gimbal Lock.

:YXZ:             
  YXZ Euler.

  YXZ Rotation Order - prone to Gimbal Lock.

:YZX:             
  YZX Euler.

  YZX Rotation Order - prone to Gimbal Lock.

:ZXY:             
  ZXY Euler.

  ZXY Rotation Order - prone to Gimbal Lock.

:ZYX:             
  ZYX Euler.

  ZYX Rotation Order - prone to Gimbal Lock.

:AXIS_ANGLE:      
  Axis Angle.

  Axis Angle (W+XYZ), defines a rotation around some axis defined by 3D-Vector.

.. _rna-enum-object-rotation-mode-items:

"""

import typing
