"""


Brush Gpencil Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

  The brush is of type used for drawing strokes.

:FILL:            
  Fill.

  The brush is of type used for filling areas.

:ERASE:           
  Erase.

  The brush is used for erasing strokes.

:TINT:            
  Tint.

  The brush is of type used for tinting strokes.

.. _rna-enum-brush-gpencil-types-items:

"""

import typing
