"""


Property Subtype Number Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:PIXEL:           
  Pixel.

:UNSIGNED:        
  Unsigned.

:PERCENTAGE:      
  Percentage.

:FACTOR:          
  Factor.

:ANGLE:           
  Angle.

:TIME:            
  Time (Scene Relative).

  Time specified in frames, converted to seconds based on scene frame rate.

:TIME_ABSOLUTE:   
  Time (Absolute).

  Time specified in seconds, independent of the scene.

:DISTANCE:        
  Distance.

:DISTANCE_CAMERA: 
  Camera Distance.

:POWER:           
  Power.

:TEMPERATURE:     
  Temperature.

:NONE:            
  None.

.. _rna-enum-property-subtype-number-items:

"""

import typing
