"""


Cloth Operators
***************

:func:`preset_add`

"""

import typing

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Cloth Preset

  :file:`startup/bl_operators/presets.py\:73 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L73>`_

  """

  ...
