"""


Space Action Mode Items
^^^^^^^^^^^^^^^^^^^^^^^

:DOPESHEET:       
  Dope Sheet.

  Edit all keyframes in scene.

:TIMELINE:        
  Timeline.

  Timeline and playback controls.

.. _rna-enum-space-action-mode-items:

"""

import typing
