"""


Keyframe Paste Offset Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:START:           
  Frame Start.

  Paste keys starting at current frame.

:END:             
  Frame End.

  Paste keys ending at current frame.

:RELATIVE:        
  Frame Relative.

  Paste keys relative to the current frame when copying.

:NONE:            
  No Offset.

  Paste keys from original time.

.. _rna-enum-keyframe-paste-offset-items:

"""

import typing
