"""


Property Override Flag Collection Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LIBRARY_OVERRIDABLE:
  Library Overridable.

  Make that property editable in library overrides of linked data-blocks.

:NO_PROPERTY_NAME:
  No Name.

  Do not use the names of the items, only their indices in the collection.

:USE_INSERTION:   
  Use Insertion.

  Allow users to add new items in that collection in library overrides.

.. _rna-enum-property-override-flag-collection-items:

"""

import typing
