"""


Stereo3D Interlace Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ROW_INTERLEAVED: 
  Row Interleaved.

:COLUMN_INTERLEAVED:
  Column Interleaved.

:CHECKERBOARD_INTERLEAVED:
  Checkerboard Interleaved.

.. _rna-enum-stereo3d-interlace-type-items:

"""

import typing
