"""


Fcurve Auto Smoothing Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  Automatic handles only take immediately adjacent keys into account.

:CONT_ACCEL:      
  Continuous Acceleration.

  Automatic handles are adjusted to avoid jumps in acceleration, resulting in smoother curves. However, key changes may affect interpolation over a larger stretch of the curve.

.. _rna-enum-fcurve-auto-smoothing-items:

"""

import typing
