"""


Property Type Items
^^^^^^^^^^^^^^^^^^^

:BOOLEAN:         
  Boolean.

:INT:             
  Integer.

:FLOAT:           
  Float.

:STRING:          
  String.

:ENUM:            
  Enumeration.

:POINTER:         
  Pointer.

:COLLECTION:      
  Collection.

.. _rna-enum-property-type-items:

"""

import typing
