"""


Fluid Operators
***************

:func:`bake_all`

:func:`bake_data`

:func:`bake_guides`

:func:`bake_mesh`

:func:`bake_noise`

:func:`bake_particles`

:func:`free_all`

:func:`free_data`

:func:`free_guides`

:func:`free_mesh`

:func:`free_noise`

:func:`free_particles`

:func:`pause_bake`

:func:`preset_add`

"""

import typing

def bake_all() -> None:

  """

  Bake Entire Fluid Simulation

  """

  ...

def bake_data() -> None:

  """

  Bake Fluid Data

  """

  ...

def bake_guides() -> None:

  """

  Bake Fluid Guiding

  """

  ...

def bake_mesh() -> None:

  """

  Bake Fluid Mesh

  """

  ...

def bake_noise() -> None:

  """

  Bake Fluid Noise

  """

  ...

def bake_particles() -> None:

  """

  Bake Fluid Particles

  """

  ...

def free_all() -> None:

  """

  Free Entire Fluid Simulation

  """

  ...

def free_data() -> None:

  """

  Free Fluid Data

  """

  ...

def free_guides() -> None:

  """

  Free Fluid Guiding

  """

  ...

def free_mesh() -> None:

  """

  Free Fluid Mesh

  """

  ...

def free_noise() -> None:

  """

  Free Fluid Noise

  """

  ...

def free_particles() -> None:

  """

  Free Fluid Particles

  """

  ...

def pause_bake() -> None:

  """

  Pause Bake

  """

  ...

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Fluid Preset

  :file:`startup/bl_operators/presets.py\:73 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L73>`_

  """

  ...
