"""


Event Direction Items
^^^^^^^^^^^^^^^^^^^^^

:ANY:             
  Any.

:NORTH:           
  North.

:NORTH_EAST:      
  North-East.

:EAST:            
  East.

:SOUTH_EAST:      
  South-East.

:SOUTH:           
  South.

:SOUTH_WEST:      
  South-West.

:WEST:            
  West.

:NORTH_WEST:      
  North-West.

.. _rna-enum-event-direction-items:

"""

import typing
