"""


Symmetrize Direction Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:NEGATIVE_X:      
  -X to +X.

:POSITIVE_X:      
  +X to -X.

:NEGATIVE_Y:      
  -Y to +Y.

:POSITIVE_Y:      
  +Y to -Y.

:NEGATIVE_Z:      
  -Z to +Z.

:POSITIVE_Z:      
  +Z to -Z.

.. _rna-enum-symmetrize-direction-items:

"""

import typing
