"""


Space Image Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:IMAGE_EDITOR:    
  Image Editor.

  View the image.

:UV:              
  UV Editor.

  UV edit in mesh editmode.

.. _rna-enum-space-image-mode-items:

"""

import typing
