"""


Texture Type Items
^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:BLEND:           
  Blend.

  Procedural - create a ramp texture.

:CLOUDS:          
  Clouds.

  Procedural - create a cloud-like fractal noise texture.

:DISTORTED_NOISE: 
  Distorted Noise.

  Procedural - noise texture distorted by two noise algorithms.

:IMAGE:           
  Image or Movie.

  Allow for images or movies to be used as textures.

:MAGIC:           
  Magic.

  Procedural - color texture based on trigonometric functions.

:MARBLE:          
  Marble.

  Procedural - marble-like noise texture with wave generated bands.

:MUSGRAVE:        
  Musgrave.

  Procedural - highly flexible fractal noise texture.

:NOISE:           
  Noise.

  Procedural - random noise, gives a different result every time, for every frame, for every pixel.

:STUCCI:          
  Stucci.

  Procedural - create a fractal noise texture.

:VORONOI:         
  Voronoi.

  Procedural - create cell-like patterns based on Worley noise.

:WOOD:            
  Wood.

  Procedural - wave generated bands or rings, with optional noise.

.. _rna-enum-texture-type-items:

"""

import typing
