"""


Brush Gpencil Weight Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:WEIGHT:          
  Weight.

  Weight Paint for Vertex Groups.

.. _rna-enum-brush-gpencil-weight-types-items:

"""

import typing
