"""


Space Type Items
^^^^^^^^^^^^^^^^

:EMPTY:           
  Empty.

.. _rna-enum-space-type-items:

**General**

:VIEW_3D:         
  3D Viewport.

  Manipulate objects in a 3D environment.

:IMAGE_EDITOR:    
  UV/Image Editor.

  View and edit images and UV Maps.

:NODE_EDITOR:     
  Node Editor.

  Editor for node-based shading and compositing tools.

:SEQUENCE_EDITOR: 
  Video Sequencer.

  Video editing tools.

:CLIP_EDITOR:     
  Movie Clip Editor.

  Motion tracking tools.

**Animation**

:DOPESHEET_EDITOR:
  Dope Sheet.

  Adjust timing of keyframes.

:GRAPH_EDITOR:    
  Graph Editor.

  Edit drivers and keyframe interpolation.

:NLA_EDITOR:      
  Nonlinear Animation.

  Combine and layer Actions.

**Scripting**

:TEXT_EDITOR:     
  Text Editor.

  Edit scripts and in-file documentation.

:CONSOLE:         
  Python Console.

  Interactive programmatic console for advanced editing and script development.

:INFO:            
  Info.

  Log of operations, warnings and error messages.

:TOPBAR:          
  Top Bar.

  Global bar at the top of the screen for global per-window settings.

:STATUSBAR:       
  Status Bar.

  Global bar at the bottom of the screen for general status information.

**Data**

:OUTLINER:        
  Outliner.

  Overview of scene graph and all available data-blocks.

:PROPERTIES:      
  Properties.

  Edit properties of active object and related data-blocks.

:FILE_BROWSER:    
  File Browser.

  Browse for files and assets.

:SPREADSHEET:     
  Spreadsheet.

  Explore geometry data in a table.

:PREFERENCES:     
  Preferences.

  Edit persistent configuration settings.

"""

import typing
