"""


Stereo3D Anaglyph Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:RED_CYAN:        
  Red-Cyan.

:GREEN_MAGENTA:   
  Green-Magenta.

:YELLOW_BLUE:     
  Yellow-Blue.

.. _rna-enum-stereo3d-anaglyph-type-items:

"""

import typing
