"""


Object Type Curve Items
^^^^^^^^^^^^^^^^^^^^^^^

:CURVE:           
  Curve.

:SURFACE:         
  Surface.

:FONT:            
  Text.

.. _rna-enum-object-type-curve-items:

"""

import typing
