"""


Property Subtype String Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILE_PATH:       
  File Path.

:DIR_PATH:        
  Directory Path.

:FILE_NAME:       
  File Name.

:BYTE_STRING:     
  Byte String.

:PASSWORD:        
  Password.

  A string that is displayed hidden ('********').

:NONE:            
  None.

.. _rna-enum-property-subtype-string-items:

"""

import typing
