"""


Poselib Operators
*****************

:func:`apply_pose_asset`

:func:`blend_pose_asset`

"""

import typing

def apply_pose_asset(blend_factor: float = 1.0, flipped: bool = False) -> None:

  """

  Apply the given Pose Action to the rig

  """

  ...

def blend_pose_asset(blend_factor: float = 0.0, flipped: bool = False, release_confirm: bool = False) -> None:

  """

  Blend the given Pose Action to the rig

  """

  ...
