"""


Dt Layers Select Src Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:ACTIVE:          
  Active Layer.

  Only transfer active data layer.

:ALL:             
  All Layers.

  Transfer all data layers.

:BONE_SELECT:     
  Selected Pose Bones.

  Transfer all vertex groups used by selected pose bones.

:BONE_DEFORM:     
  Deform Pose Bones.

  Transfer all vertex groups used by deform bones.

.. _rna-enum-dt-layers-select-src-items:

"""

import typing
