"""


Dt Method Poly Items
^^^^^^^^^^^^^^^^^^^^

:TOPOLOGY:        
  Topology.

  Copy from identical topology meshes.

:NEAREST:         
  Nearest Face.

  Copy from nearest polygon (using center points).

:NORMAL:          
  Best Normal-Matching.

  Copy from source polygon which normal is the closest to destination one.

:POLYINTERP_PNORPROJ:
  Projected Face Interpolated.

  Interpolate all source polygons intersected by the projection of destination one along its own normal.

.. _rna-enum-dt-method-poly-items:

"""

import typing
