"""


Transform Mode Types
^^^^^^^^^^^^^^^^^^^^

:INIT:            
  Init.

:DUMMY:           
  Dummy.

:TRANSLATION:     
  Translation.

:ROTATION:        
  Rotation.

:RESIZE:          
  Resize.

:SKIN_RESIZE:     
  Skin Resize.

:TOSPHERE:        
  To Sphere.

:SHEAR:           
  Shear.

:BEND:            
  Bend.

:SHRINKFATTEN:    
  Shrink/Fatten.

:TILT:            
  Tilt.

:TRACKBALL:       
  Trackball.

:PUSHPULL:        
  Push/Pull.

:CREASE:          
  Crease.

:VERTEX_CREASE:   
  Vertex Crease.

:MIRROR:          
  Mirror.

:BONE_SIZE:       
  Bone Size.

:BONE_ENVELOPE:   
  Bone Envelope.

:BONE_ENVELOPE_DIST:
  Bone Envelope Distance.

:CURVE_SHRINKFATTEN:
  Curve Shrink/Fatten.

:MASK_SHRINKFATTEN:
  Mask Shrink/Fatten.

:GPENCIL_SHRINKFATTEN:
  Grease Pencil Shrink/Fatten.

:BONE_ROLL:       
  Bone Roll.

:TIME_TRANSLATE:  
  Time Translate.

:TIME_SLIDE:      
  Time Slide.

:TIME_SCALE:      
  Time Scale.

:TIME_EXTEND:     
  Time Extend.

:BAKE_TIME:       
  Bake Time.

:BWEIGHT:         
  Bevel Weight.

:ALIGN:           
  Align.

:EDGESLIDE:       
  Edge Slide.

:SEQSLIDE:        
  Sequence Slide.

:GPENCIL_OPACITY: 
  Grease Pencil Opacity.

.. _rna-enum-transform-mode-types:

"""

import typing
